@@ -2,17 +2,17 @@
 select setting::int < 140000 as pg12_13 from pg_settings where name = 'server_version_num';
 
 -- json output
-select pgsp_format_json();
+set pg_show_plans.plan_format = 'json';
 show pg_show_plans.plan_format;
 select * from nest();
 
 -- yaml output
-select pgsp_format_yaml();
+set pg_show_plans.plan_format = 'yaml';
 show pg_show_plans.plan_format;
 select * from nest();
 
 -- xml output
-select pgsp_format_xml();
+set pg_show_plans.plan_format = 'xml';
 show pg_show_plans.plan_format;
 select * from nest();
 
